@@ -105,11 +105,7 @@ ev_message_area_init (EvMessageArea *area)
 	gtk_label_set_use_markup (GTK_LABEL (area->priv->label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (area->priv->label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (area->priv->label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (area->priv->label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (area->priv->label), 0.0, 0.5);
-#endif
 	gtk_widget_set_can_focus (area->priv->label, TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), area->priv->label, TRUE, TRUE, 0);
 	gtk_widget_show (area->priv->label);
@@ -118,11 +114,7 @@ ev_message_area_init (EvMessageArea *area)
 	gtk_label_set_use_markup (GTK_LABEL (area->priv->secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (area->priv->secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (area->priv->secondary_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (area->priv->secondary_label), 0.0);
-#else
-	gtk_misc_set_alignment (GTK_MISC (area->priv->secondary_label), 0.0, 0.5);
-#endif
 	gtk_widget_set_can_focus (area->priv->secondary_label, TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), area->priv->secondary_label, TRUE, TRUE, 0);
 
@@ -148,7 +140,6 @@ ev_message_area_set_image_for_type (EvMessageArea *area,
 				    GtkMessageType type)
 {
 	const gchar *icon_name = NULL;
-	const gchar *stock_id = NULL;
 	AtkObject   *atk_obj;
 
 	switch (type) {
@@ -178,10 +169,8 @@ ev_message_area_set_image_for_type (EvMessageArea *area,
 	atk_obj = gtk_widget_get_accessible (GTK_WIDGET (area));
 	if (GTK_IS_ACCESSIBLE (atk_obj)) {
 		atk_object_set_role (atk_obj, ATK_ROLE_ALERT);
-		if (stock_id) {
-			GtkStockItem item;
-			gtk_stock_lookup (stock_id, &item);
-			atk_object_set_name (atk_obj, item.label);
+		if (icon_name) {
+			atk_object_set_name (atk_obj, icon_name);
 		}
 	}
 }
